@@ -75,8 +75,8 @@ int main(int argc, char *argv[])
         viewer.engine()->setNetworkAccessManagerFactory(factory);
 
 #ifdef Q_WS_MAEMO_5
-        //        viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
-        //    viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
+        viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
+        viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
         viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
         QDir path;
         path.setPath("/home/user/.config/cutetube");
@@ -87,7 +87,7 @@ int main(int argc, char *argv[])
         if (!path.exists()) {
             path.mkpath("/home/user/MyDocs/.cutetube");
         }
-//        viewer.setViewport(new QGLWidget());
+        //        viewer.setViewport(new QGLWidget());
 
         QString locale = ct.getLanguage();
 
