@@ -57,10 +57,53 @@ void YouTube::checkLogin() {
     else {
         setAccessToken(token);
         emit alert(tr("You are signed in to YouTube as '") + getCurrentUser() + "'");
+        siteLogin();
     }
     reply->deleteLater();
 }
 
+void YouTube::siteLogin() {
+    QNetworkRequest request(QUrl("https://www.youtube.com/signup?next=/&gl=US&hl=en"));
+    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.12) Gecko/20101028 Firefox/3.6.12");
+    request.setRawHeader("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
+    request.setRawHeader("Accept-Language", "en-us,en;q=0.5");
+    request.setRawHeader("Accept-Charset", "ISO-8859-1,utf-8;q=0.7,*;q=0.7");
+    QByteArray loginData("current_form=loginForm&next=/&action_login=Log In&username=mythmarx&password=stuhowarth1977");
+    QNetworkReply* reply = nam->post(request, loginData.toPercentEncoding());
+    connect(reply, SIGNAL(finished()), this, SLOT(checkSiteLogin()));
+}
+
+void YouTube::checkSiteLogin() {
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    if (!reply) {
+        qDebug() << "Error - no reply";
+        return;
+    }
+
+    QByteArray response = reply->readAll();
+//    qDebug() << response;
+    QNetworkRequest request(QUrl("http://www.youtube.com/verify_age?next_url=/&gl=US&hl=en"));
+    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.12) Gecko/20101028 Firefox/3.6.12");
+    request.setRawHeader("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
+    request.setRawHeader("Accept-Language", "en-us,en;q=0.5");
+    request.setRawHeader("Accept-Charset", "ISO-8859-1,utf-8;q=0.7,*;q=0.7");
+    QByteArray ageData("next_url=/&action_confirm=Confirm");
+    reply = nam->post(request, ageData.toPercentEncoding());
+    connect(reply, SIGNAL(finished()), this, SLOT(checkAgeVerification()));
+}
+
+void YouTube::checkAgeVerification() {
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    if (!reply) {
+        qDebug() << "Error - no reply";
+        return;
+    }
+
+//    QByteArray response = reply->readAll();
+//    qDebug() << response;
+    reply->deleteLater();
+}
+
 void YouTube::setCurrentUser(const QString &user) {
     currentUser = user;
     emit currentUserChanged();
@@ -356,6 +399,11 @@ void YouTube::getVideoUrl(const QString &playerUrl) {
     request.setUrl(QUrl(playerUrl));
     connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(parseVideoPage(QNetworkReply*)));
     manager->get(request);
+
+//    QNetworkRequest request;
+//    request.setUrl(QUrl(playerUrl));
+//    QNetworkReply *reply = nam->get(request);
+//    connect(reply, SIGNAL(finished()), this, SLOT(parseVideoPage()));
 }
 
 void YouTube::parseVideoPage(QNetworkReply *reply) {
@@ -363,6 +411,7 @@ void YouTube::parseVideoPage(QNetworkReply *reply) {
 
     QMap<int, QByteArray> formats;
     QByteArray response = reply->readAll();
+//    qDebug() << response;
     response = response.simplified().replace(QByteArray(" "), QByteArray(""));
     int pos = response.indexOf("\",\"fmt_url_map\":\"") + 17;
     int pos2 = response.indexOf('\"', pos);
@@ -391,7 +440,49 @@ void YouTube::parseVideoPage(QNetworkReply *reply) {
     else {
         emit gotVideoUrl(QString(videoUrl));
     }
+//    qDebug() << videoUrl;
     reply->deleteLater();
     manager->deleteLater();
 }
 
+void YouTube::parseVideoPage() {
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    if (!reply) {
+        return;
+    }
+
+    QMap<int, QByteArray> formats;
+    QByteArray response = reply->readAll();
+//    qDebug() << response;
+    response = response.simplified().replace(QByteArray(" "), QByteArray(""));
+    int pos = response.indexOf("\",\"fmt_url_map\":\"") + 17;
+    int pos2 = response.indexOf('\"', pos);
+    response = response.mid(pos, pos2 - pos);
+    QList<QByteArray> parts = response.split('|');
+    int key = parts.first().toInt();
+    for (int i = 1; i < parts.length(); i++) {
+        QByteArray part = parts[i];
+        QList<QByteArray> keyAndValue = part.split(',');
+        QByteArray url = keyAndValue.first().replace(QByteArray("\\/"), QByteArray("/")).replace(QByteArray("\\u0026"), QByteArray("&"));
+        formats[key] = url;
+        key = keyAndValue.last().toInt();
+    }
+    QList<int> flist;
+    flist << 22 << 35 << 34 << 18 << 5;
+    QByteArray videoUrl = "";
+    int index = flist.indexOf(playbackFormat);
+    while ((videoUrl == "") && index < flist.size()) {
+        videoUrl = formats.value(flist.at(index), "");
+        index++;
+    }
+    if (videoUrl == "") {
+        emit alert(tr("Error: Unable to retrieve video"));
+        emit videoUrlError();
+    }
+    else {
+        emit gotVideoUrl(QString(videoUrl));
+    }
+//    qDebug() << videoUrl;
+    reply->deleteLater();
+}
+
